{{- $clientDefaultAttributes := (dict "protocol" "openid-connect" "publicClient" true) -}}
{{- $clients := (list) -}}
{{- range .Values.keycloak.realm.clients -}}
{{-   $client := (merge . $clientDefaultAttributes) -}}
{{-   $_ := set $client "id" (uuidv4) -}}
{{-   $rendered_client := (dict) -}}
{{-   range $key, $value := $client -}}
{{-     if (kindIs "slice" $value) -}}
{{-       $rendered_array := (list) -}}
{{-       range $value -}}
{{-         if (kindIs "string" .) -}}
{{-           $rendered_array = append $rendered_array (tpl . $) -}}
{{-         else -}}
{{-           $rendered_array = append $rendered_array . -}}
{{-         end -}}
{{-       end -}}
{{-       $_ := set $rendered_client $key $rendered_array -}}
{{-     else if (kindIs "string" $value) -}}
{{-       $_ := set $rendered_client $key (tpl $value $) -}}
{{-     else -}}
{{-       $_ := set $rendered_client $key $value -}}
{{-     end -}}
{{-   end -}}
{{-   $clients = append $clients $rendered_client -}}
{{- end -}}

{{/*
      Client roles
*/}}
{{- $clientRoles :=  (dict) }}
{{- range $index, $roles_for_client := .Values.keycloak.realm.clientRoles -}}
{{-   $clientName := (index $clients $index).clientId -}}
{{-   $clientId   := (index $clients $index).id -}}
{{-   $generated_roles := (list) -}}
{{-   range $roles_for_client.content -}}
{{-     $_ := set . "containerId" $clientId -}}
{{-     $_ := set . "clientRole" true -}}
{{-     $generated_roles = append $generated_roles . -}}
{{-   end -}}
{{-   $_ := set $clientRoles $clientName $generated_roles -}}
{{- end -}}

{{/*
      Realm roles
*/}}
{{- $realmRoles := (list) -}}
{{- range $_, $role := .Values.keycloak.realm.realmRoles -}}
{{-   $_ := set . "clientRole" false -}}
{{-   $realmRoles = append $realmRoles $role -}}
{{- end -}}

{{/*
      Realm groups
*/}}
{{- $realmGroups := (list) -}}
{{- range $_, $group := .Values.keycloak.realm.realmGroups -}}
{{-   $realmGroups = append $realmGroups $group -}}
{{- end -}}

{{/*
      Identity providers
*/}}
{{- $identityProviders := (list) -}}
{{- $identityProviderMappers := (list) -}}
{{- range $IdPName, $IdP := .Values.keycloak.externalIdP -}}
{{- $identityProvider := (dict) -}}
{{- $_ := set $identityProvider "alias" $IdPName -}}
{{- $_ := set $identityProvider "providerId" $IdPName -}}
{{- $_ := set $identityProvider "config" $IdP.config -}}
{{- $_ := set $identityProvider "enabled" $IdP.enabled -}}
{{- range $_, $IdPMapper := $IdP.mappers -}}
{{- $identityProviderMapper := (dict) -}}
{{- $_ := set $identityProviderMapper "identityProviderMapper" $IdPMapper.type -}}
{{- $_ := set $identityProviderMapper "name" $IdPMapper.name -}}
{{- $_ := set $identityProviderMapper "identityProviderAlias" $IdPName -}}
{{- $_ := set $identityProviderMapper "config" $IdPMapper.config -}}
{{- $identityProviderMappers = append $identityProviderMappers $identityProviderMapper -}}
{{- end -}}
{{- $identityProviders = append $identityProviders $identityProvider -}}
{{- end -}}

{
  "id": "{{ .Values.keycloak.realm.name }}",
  "realm": "{{ .Values.keycloak.realm.name }}",
  "displayName": "{{ .Values.keycloak.realm.displayName }}",
  "enabled": true,
  "loginTheme": "MDS",
  "accountTheme": "MDS",
  "adminTheme": "MDS",
  "sslRequired": "{{ .Values.keycloak.realm.sslRequired }}",
  "clients": {{ toPrettyJson $clients | nindent 2 }},
  "roles": {
    "client": {{- toPrettyJson $clientRoles | nindent 4 -}},
    "realm": {{- toPrettyJson $realmRoles | nindent 4 -}}
  },
{{- if $realmGroups }}
  "groups": {{- toPrettyJson $realmGroups | nindent 2 }},
{{- end }}
  "identityProviders": {{- toPrettyJson $identityProviders | nindent 4 -}},
  "identityProviderMappers": {{- toPrettyJson $identityProviderMappers | nindent 4 -}},
  "userFederationProviders": {{- toPrettyJson .Values.keycloak.userFederation.providers | nindent 4 -}},
  "userFederationMappers": {{- toPrettyJson .Values.keycloak.userFederation.mappers | nindent 4 -}}
}
