{{/* vim: set filetype=mustache: */}}

{{/*
    NOTE(pbrit): Borrowed from here: https://github.com/helm/helm/issues/4535#issuecomment-416022809
*/}}

{{- define "call-nested" }}
{{- $dot := index . 0 }}
{{- $subchart := index . 1 }}
{{- $template := index . 2 }}
{{- include $template (dict "Chart" (dict "Name" $subchart) "Values" (index $dot.Values $subchart) "Release" $dot.Release "Capabilities" $dot.Capabilities) }}
{{- end }}


{{/*
Expand the name of IAM-API.
*/}}
{{- define "iam.api.name" -}}
    {{- default "iam-api" .Values.api.nameOverride | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
Create a default fully qualified app name.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
If release name contains chart name it will be used as a full name.
*/}}
{{- define "iam.fullname" -}}
    {{- if .Values.fullnameOverride -}}
        {{- .Values.fullnameOverride | trunc 63 | trimSuffix "-" -}}
    {{- else -}}
        {{- $name := default "iam" .Values.nameOverride -}}
        {{- if contains $name .Release.Name -}}
            {{- .Release.Name | trunc 63 | trimSuffix "-" -}}
        {{- else -}}
            {{- printf "%s-%s" .Release.Name $name | trunc 63 | trimSuffix "-" -}}
        {{- end -}}
    {{- end -}}
{{- end -}}

{{/*
Create chart name and version as used by the chart label.
*/}}
{{- define "iam.chart" -}}
    {{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
Create selector labels
*/}}
{{- define "iam.selectorLabels" -}}
app.kubernetes.io/name: {{ include "iam.api.name" . }}
app.kubernetes.io/instance: {{ .Release.Name }}
{{- end -}}

{{/*
    The url to the Keycloak instance
*/}}
{{- define "iam.keycloak-url" -}}
{{- if .Values.keycloak.keycloak.ingress.enabled -}}
    {{- printf "https://%s" (first .Values.keycloak.keycloak.ingress.hosts) -}}
{{- else -}}
    {{- default (printf "http://%s-http:%s" (include "call-nested" (list . "keycloak" "keycloak.fullname")) (include "iam.keycloak-port" .)) .Values.api.keycloak.url -}}
{{- end -}}
{{- end -}}

{{/*
    The TCP port where for the Keycloak listens for the incoming connections.
*/}}
{{- define "iam.keycloak-port" -}}
    {{- default .Values.keycloak.keycloak.service.port .Values.api.keycloak.port -}}
{{- end -}}


{{/*
    The username in the master realm in the Keycloak instance.
    This username is used for the initial bootstrap and by IAM API.
*/}}
{{- define "iam.keycloak-master-username" -}}
    {{- default .Values.api.keycloak.admin.username .Values.keycloak.keycloak.username -}}
{{- end -}}
